/* Controlling the TeleToyland Marble Maze with Buttons for Local Shows

   4 pushbuttons are connected pins 2,3,4, and 5 for up, down, right and left
     - the inputs are connected to ground with 10K ohm resistors, and the switches connect 
       the inputs to +
   2 hobby servos are connected to pins 9 & 10
   
   by Carl Sutter
   June 2013
 */

#include <Servo.h> 
 
const int buttonPinU = 3;     // up pushbutton pin
const int buttonPinD = 2;     // down pushbutton pin
const int buttonPinL = 4;     // left pushbutton pin
const int buttonPinR = 5;     // right pushbutton pin
 
Servo servoRoll;   // left/right servo object
Servo servoPitch;  // up/down servo object

const int roll_L = 120; // the servo position for Left tilt
const int roll_M = 98;  // the servo position to center the lef/right servo
const int roll_R = 76;  // the servo position for Right tilt

const int pitch_U = 120; // servo up position
const int pitch_M = 98;  // up/down center
const int pitch_D = 76;  // servo down position

const int delay_step = 20;   // short delay for slow servo move loops
const int delay_hold = 500;  // the delay time to hold from tilt in one direction, then tilt back

int pos = 0;    // variable to store the servo position 
 
void setup() 
{ 
  servoPitch.attach(9);  // connect the pitch (up/down) servo to pin 9
  servoRoll.attach(10);  // connect the roll (right/left) servo to pin 10

  servoRoll.write(roll_M);  // center the servos to start
  servoPitch.write(pitch_M);

  pinMode(buttonPinU, INPUT);  // setup the push buttons for input mode   
  pinMode(buttonPinD, INPUT);     
  pinMode(buttonPinL, INPUT);     
  pinMode(buttonPinR, INPUT);     
} 
 
void loop() 
{ 
  // UP Button - for each of these slowly tilt, then pause for the marble to roll, then slowly tilt back
  if (digitalRead(buttonPinU) == HIGH) {     
    for(pos = pitch_M; pos <= pitch_U; pos += 1) {
      servoPitch.write(pos);
      delay(delay_step);
    }
    delay(delay_hold);
    for(pos = pitch_U; pos >= pitch_M; pos -= 1) {
      servoPitch.write(pos);
      delay(delay_step);
    }
  } // UP


  // DOWN Button
  if (digitalRead(buttonPinD) == HIGH) {     
    for(pos = pitch_M; pos >= pitch_D; pos -= 1) {
      servoPitch.write(pos);
      delay(delay_step);
    }
    delay(delay_hold);
    for(pos = pitch_D; pos <= pitch_M; pos += 1) {
      servoPitch.write(pos);
      delay(delay_step);
    }
  } // DOWN

 
  // LEFT Button
  if (digitalRead(buttonPinL) == HIGH) {     
    for(pos = roll_M; pos <= roll_L; pos += 1) {
      servoRoll.write(pos);
      delay(delay_step);
    }
    delay(delay_hold);
    for(pos = roll_L; pos >= roll_M; pos -= 1) {
      servoRoll.write(pos);
      delay(delay_step);
    }
  } // LEFT


  // RIGHT Button
  if (digitalRead(buttonPinR) == HIGH) {     
    for(pos = roll_M; pos >= roll_R; pos -= 1) {
      servoRoll.write(pos);
      delay(delay_step);
    }
    delay(delay_hold);
    for(pos = roll_R; pos <= roll_M; pos += 1) {
      servoRoll.write(pos);
      delay(delay_step);
    }
  } // RIGHT

} // loop
